@@ -84,13 +84,12 @@ class Model:
                 # x_train_cols does not include temp column because it can make
                 # a variable number of extra columns depending on modeling algo
                 self.x_train_cols = list(self.df.drop(
-                    columns=[x for x in not_x_cols if x is not None]).columns)
+                    columns=[x for x in not_x_cols if x is not None], axis=1).columns)
                 try:
                     self.df[[dependent_col]]
                 except KeyError:
                     raise KeyError(
-                        "Supplied dependent variable column name is " +
-                        dependent_col + " but it was not found in the supplied"
+                        "Supplied dependent variable column name is but it was not found in the supplied"
                         " dataframe.")
             else:
                 raise ValueError("Supplied dataset is not a pandas dataframe.")
